# Estatistica

Descricao. 
Este pacote eh usado para:
	- funcoes simples de estatistica  
	- apresentar resultados dos calculos

## Instalacao

Use gerenciador de pacote [pip](https://pip.pypa.io/en/stable/) para instalar o pacote package_estatistica

```bash
pip install package_estatistica
```

## Utilizacao

```python
from package_estatistica.funcoes import principal
```

## Autor
Alessandro Miranda Goncalves

## Licença
[MIT](https://choosealicense.com/licenses/mit/)